@@ -11,8 +11,8 @@
 #include <QColor>
 #include <QWidget>
 
-#include <libkomparediff2/difference.h>
-#include <libkomparediff2/settingsbase.h>
+#include <KompareDiff2/Difference>
+#include <KompareDiff2/SettingsBase>
 
 #include "dialogpages_export.h"
 
