@@ -15,10 +15,10 @@
 #include <KPluginMetaData>
 #include <KPluginFactory>
 
-#include <libkomparediff2/difference.h>
-#include <libkomparediff2/diffmodel.h>
-#include <libkomparediff2/diffmodellist.h>
-#include <libkomparediff2/komparemodellist.h>
+#include <KompareDiff2/Difference>
+#include <KompareDiff2/DiffModel>
+#include <KompareDiff2/DiffModelList>
+#include <KompareDiff2/KompareModelList>
 
 #include <komparenavviewdebug.h>
 
@@ -30,7 +30,11 @@ using namespace Diff2;
 
 KompareNavTreePart::KompareNavTreePart(QWidget* parentWidget, QObject* parent,
                                        const KPluginMetaData& metaData, const QVariantList&)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    : KParts::ReadOnlyPart(parent, metaData),
+#else
     : KParts::ReadOnlyPart(parent),
+#endif
       m_splitter(nullptr),
       m_modelList(nullptr),
       m_srcDirTree(nullptr),
@@ -45,7 +49,9 @@ KompareNavTreePart::KompareNavTreePart(QWidget* parentWidget, QObject* parent,
       m_destination(),
       m_info(nullptr)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     setMetaData(metaData);
+#endif
 
     m_splitter = new QSplitter(Qt::Horizontal, parentWidget);
 
@@ -768,3 +774,4 @@ K_PLUGIN_FACTORY_WITH_JSON(KompareNavTreePartFactory, "komparenavtreepart.json",
                            registerPlugin<KompareNavTreePart>();)
 
 #include "komparenavtreepart.moc"
+#include "moc_komparenavtreepart.cpp"
