@@ -39,8 +39,8 @@
 #include <KIO/FileCopyJob>
 #include <KIO/MkdirJob>
 
-#include <libkomparediff2/diffmodel.h>
-#include <libkomparediff2/diffsettings.h>
+#include <KompareDiff2/DiffModel>
+#include <KompareDiff2/DiffSettings>
 
 #include <komparepartdebug.h>
 #include "komparelistview.h"
@@ -57,10 +57,16 @@ ViewSettings* KomparePart::m_viewSettings = nullptr;
 DiffSettings* KomparePart::m_diffSettings = nullptr;
 
 KomparePart::KomparePart(QWidget* parentWidget, QObject* parent, const KPluginMetaData& metaData, Modus modus) :
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    KParts::ReadWritePart(parent, metaData),
+#else
     KParts::ReadWritePart(parent),
+#endif
     m_info()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     setMetaData(metaData);
+#endif
 
     // set our XML-UI resource file
     setXMLFile(QStringLiteral("komparepartui.rc"));
@@ -82,7 +88,7 @@ KomparePart::KomparePart(QWidget* parentWidget, QObject* parent, const KPluginMe
     m_splitter = m_view->splitter();
 
     // This creates the "Model creator" and connects the signals and slots
-    m_modelList = new Diff2::KompareModelList(m_diffSettings, m_splitter, this, "komparemodellist" , (modus == ReadWriteModus));
+    m_modelList = new Diff2::KompareModelList(m_diffSettings, this, "komparemodellist" , (modus == ReadWriteModus));
 
     const auto modelListActions = m_modelList->actionCollection()->actions();
     for (QAction* action : modelListActions) {
@@ -971,3 +977,5 @@ void KomparePart::optionsPreferences()
     if (pref.exec())
         Q_EMIT configChanged();
 }
+
+#include "moc_kompare_part.cpp"
