@@ -11,7 +11,6 @@
 
 #include <QStyle>
 #include <QPainter>
-#include <QRegExp>
 #include <QTimer>
 #include <QResizeEvent>
 #include <QMouseEvent>
@@ -20,10 +19,10 @@
 
 #include <KSharedConfig>
 
-#include <libkomparediff2/diffmodel.h>
-#include <libkomparediff2/diffhunk.h>
-#include <libkomparediff2/difference.h>
-#include <libkomparediff2/komparemodellist.h>
+#include <KompareDiff2/DiffModel>
+#include <KompareDiff2/DiffHunk>
+#include <KompareDiff2/Difference>
+#include <KompareDiff2/KompareModelList>
 
 #include <komparepartdebug.h>
 #include "viewsettings.h"
@@ -960,3 +959,5 @@ void KompareListViewHunkItem::paintCell(QPainter* p, const QStyleOptionViewItem&
         }
     }
 }
+
+#include "moc_komparelistview.cpp"
